<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Request;
use App\Models\Client; 
use App\Models\Representant; 
use App\Models\User; 
use DB;
use Session; 

class ClientController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
           
        $clients = Client::all(); 
        
        return view('client.index')->with('clients', $clients); 
    }

    public function addAccount(Request $request) 
    {
        $user = DB::table('users')->where('client_id', '=', $request->id_client)->get(); 
        
        $client = Client::find($request->id_client); 

        if($client->adresse_email == null && $client->telephone == null) {
            Session::flash('info', "Ce client n'a ni email ni numero de telephone !"); 
            return redirect()->back(); 
        }

        if($user->count() != 0) {
            Session::flash('info', 'Ce client a deja un compte !'); 
            return redirect()->back(); 
        } 

        $this->validate($request, [
            'password' => 'required|confirmed'
        ]); 
       // $compte = DB::table('users')->where('client_id', '=', $request->id_client)->get(); 
        //dd($compte); 

        
        //dd($client->id); 

        $identifiant = ''; 

        if($client->adresse_email != null) 
        {
            $identifiant = $client->adresse_email; 
        }

        if($client->telephone != null) 
        {
            $identifiant = $client->telephone; 
        }

        User::create([
            'client_id' => $request->id_client, 
            'nom' => $client->nom, 
            'prenom' => $client->prenom, 
            'email' => $identifiant, 
            'password' => Hash::make($request->password),
            'profile_photo_path' => $client->photo, 
            'type' => 'client'
        ]);  

        return redirect()->route('utilisateur.index'); 

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $representants = Representant::all(); 

        return view('client.create')->with('representants', $representants); 
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validate($request, [
            'nom' => 'required', 
            'prenom' => 'required'
        ]); 
        
        $fileName = ''; 

        if($request->photo != null){
            $fileName = time().'.'.$request->photo->extension();  

            $request->photo->move(public_path('uploads/photo'), $fileName);
        } 
      
        Client::create([
            'representant_id' => $request->representant_id, 
            'nom' => $request->nom, 
            'prenom' => $request->prenom, 
            'telephone' => $request->telephone, 
            'adresse_email' => $request->adresse_email, 
            'numero_cin_passeport' => $request->numero_cin_passeport, 
            'nationalite' => $request->nationalite, 
            'residence' => $request->residence,
            'photo'=> $fileName 
        ]); 

        Session::flash('success', 'Client cree avec succee !'); 
        
        return redirect()->route('client.index'); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
        $client = Client::find($id); 
 
        return view('client.view')->with('client', $client); 
    } 

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $client = Client::find($id); 

        $representants = Representant::all(); 

        return view('client.edit')->with('client', $client)->with('representants', $representants); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    
        $this->validate($request, [
            'nom' => 'required', 
            'prenom' => 'required',
            'telephone' => 'required'
        ]); 
        
        $client = Client::find($id); 
            
        $client->nom = $request->nom; 
        $client->prenom = $request->prenom; 
        $client->telephone = $request->telephone; 
        $client->adresse_email = $request->adresse_email; 
        $client->numero_cin_passeport = $request->numero_cin_passeport; 
        $client->residence = $request->residence; 
        if($request->representant_id != null)
            $client->representant_id = $request->representant_id; 
        
        $client->save();
        
        Session::flash('success', 'Client modifie avec succee !'); 
        return redirect()->route('client.index'); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request) {
        Client::destroy($request->id_client); 

        Session::flash('success', 'Client Supprime avec succee !'); 
        return redirect()->route('client.index'); 
    }
}
