<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth; 
use DB; 
use App\Models\Client; 
use App\Models\Programme; 
use App\Models\Dossier; 
use App\Models\Agent; 
use App\Models\Parcelle; 
use App\Models\Versement; 
use Carbon\Carbon; 
use Session; 

class DossierController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        
        $dossiers = DB::table('dossiers')
            ->join('clients', 'clients.id', '=', 'dossiers.client_id')
            ->join('agents', 'agents.id', '=', 'dossiers.agent_id')
            ->join('programmes', 'programmes.id', '=', 'dossiers.programme_id')
            ->select('dossiers.id', 'clients.id as client_id', 'clients.nom as client_nom', 'clients.prenom as client_prenom', 'dossiers.reference' ,'dossiers.created_at', 'dossiers.etat', 'dossiers.montant_contrat', 'dossiers.montant_verse', 'agents.nom as agent_nom', 'agents.prenom as agent_prenom', 'programmes.site', 'dossiers.date')
            ->orderBy('dossiers.id', 'desc')
            ->get();
        
        $versements = DB::table('versements')
            ->select(DB::raw('SUM(montant) as total'), 'dossier_id')
            ->groupBy('dossier_id')->orderBy('dossier_id', 'desc')
            ->get(); 

        $parcelles = DB::table('parcelles')
        ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
        ->select('parcelles.id', 'programmes.site', 'parcelles.numero', 'parcelles.surface')
        ->where('parcelles.etat', '=', 'non réservé')
        ->get(); 

         //   dd($versements); 

        return view('dossier.index')
        ->with('dossiers', $dossiers)
        ->with('versements', $versements)
        ->with('parcelles', $parcelles); 
    }

  

    public function MesDossiers()
    {
        
        $dossiers = DB::table('dossiers')
        ->join('clients', 'clients.id', '=', 'dossiers.client_id')
        ->join('agents', 'agents.id', '=', 'dossiers.agent_id')
        ->select('dossiers.id', 'clients.id as client_id', 'clients.nom as client_nom', 'clients.prenom as client_prenom', 'dossiers.reference', 'dossiers.montant_contrat', 'dossiers.montant_verse' ,'dossiers.created_at', 'dossiers.etat', 'agents.nom as agent_nom', 'agents.prenom as agent_prenom')
        ->where('dossiers.client_id', '=', Auth::user()->client_id) 
        ->get();
    
        return view('dossier.mes_dossiers')->with('dossiers', $dossiers); 
    }

    public function listeDossierClient() {

        $dossiers = DB::table('dossiers')->where('client_id', '=', Auth::user()->client_id)->get(); 
        
        return view('espace_client.index')->with('dossiers', $dossiers);    
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
       
        $clients = Client::all(); 

        $programmes = DB::table('parcelles')
        ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
        ->select('parcelles.id', 'programmes.site', 'parcelles.id as parcelle_id', 'parcelles.numero', 'parcelles.surface')
        ->where('id_client', '=', 0)
        ->get();

        $parcelle_dispos = DB::table('parcelles')
        ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
        ->select('parcelles.id', 'programmes.site', 'parcelles.id as parcelle_id', 'parcelles.numero', 'parcelles.surface')
        ->where('parcelles.etat', '=', 'non réservé')->get(); 

        $agents = Agent::all(); 
        
        return view('dossier.create')
                ->with('clients', $clients)
                ->with('programmes', $programmes)
                ->with('parcelle_dispos', $parcelle_dispos) 
                ->with('agents', $agents); 
    }

    public function reservation(Request $request) 
    {
        $parcelle_dispo = DB::table('parcelles')->where('etat', '=', 'non réservé')->get(); 

        if($parcelle_dispo->count() == 0)
        {
            Session::flash('info', 'Parcelle indisponible !'); 
            return redirect()->back(); 
        } 

        $parcelle = Parcelle::find($request->parcelle); 
        $parcelle->id_dossier = $request->dossier_id;
        $parcelle->id_client = $request->client_id; 
        $parcelle->etat = 'réservé'; 
        $parcelle->save(); 

        Session::flash('success', 'Opération effectué');

        return redirect()->back();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
  
        $this->validate($request, [
            'client' => 'required', 
            'parcelle_dispo' => 'required', 
            'date' => 'required', 
            'duree_contrat' => 'required|integer',
            'montant' => 'required'
        ]); 
        
        $programme = DB::table('programmes')
        ->join('parcelles', 'parcelles.id_site', '=', 'programmes.id')
        ->select('programmes.id', 'programmes.site')
        ->where('parcelles.id', '=', $request->parcelle_dispo[0])->get();
        
        $dossier = Dossier::create([
            'client_id' => $request->client, 
            'agent_id' => $request->agent_id, 
            'programme_id' => $programme[0]->id,
            'date' => $request->date, 
            'reference' => 1 /*($client->prenom)[0].''.($client->nom)[0]. '00'. (Dossier::count() + 1)*/, 
            'duree_contrat' => $request->duree_contrat, 
            'etat' => 'ouvert', 
            'montant_contrat' => $request->montant, 
            'montant_verse' => 0,
        ]); 

        foreach($request->parcelle_dispo as $pd)
        {
            $parcelle = Parcelle::find($pd); 
            $parcelle->id_client = $request->client; 
            $parcelle->etat = 'réservé'; 
            $parcelle->id_dossier = $dossier->id; 
            $parcelle->save(); 
        }
        

        Session::flash('success', 'Dossier ajoute avec succée !'); 
        
        return redirect()->route('dossier.index'); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
       $dossier = DB::table('dossiers')
        ->join('clients', 'clients.id', '=', 'dossiers.client_id')
        ->join('agents', 'agents.id', '=', 'dossiers.agent_id')
        ->join('programmes', 'programmes.id', 'dossiers.programme_id')
        ->select('dossiers.id', 'dossiers.programme_id', 'dossiers.date', 'dossiers.duree_contrat', 'dossiers.etat',
        'dossiers.montant_contrat', '.dossiers.montant_verse', 
        'dossiers.client_id', 'clients.nom as client_nom', 'clients.prenom as client_prenom',
        'agents.nom as agent_nom', 'agents.prenom as agent_prenom',
        'programmes.site')
        ->where('dossiers.id', '=', $id)->get(); 
        
        $parcelles = DB::table('parcelles')
        ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
        ->select('parcelles.id' , 'parcelles.numero', 'parcelles.surface')
        ->where('id_client', '=', $dossier[0]->client_id)
        ->where('programmes.id', '=', $dossier[0]->programme_id)
        ->get();

        $versements = DB::table('versements')
        ->join('dossiers', 'dossiers.id', '=', 'versements.dossier_id')
        ->join('clients', 'clients.id', '=', 'versements.client_id')
        ->select('versements.id', 'versements.dossier_id', 'versements.libelle', 'versements.montant', 'versements.date',
        'clients.nom as client_nom', 'clients.prenom as client_prenom')
        ->where('dossiers.id', '=', $id)->get(); 
        
        return view('dossier.show')->with('dossier', $dossier)
        ->with('versements', $versements)
        ->with('parcelles', $parcelles); 

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
   
        $dossier = DB::table('dossiers')
        ->join('clients', 'clients.id', '=', 'dossiers.client_id')
        ->join('agents', 'agents.id', '=', 'dossiers.agent_id')
        ->join('programmes', 'programmes.id', 'dossiers.programme_id')
        ->select('dossiers.id', 'dossiers.programme_id', 'dossiers.date', 'dossiers.duree_contrat', 'dossiers.etat',
        'dossiers.montant_contrat', '.dossiers.montant_verse', 
        'dossiers.client_id', 'clients.nom as client_nom', 'clients.prenom as client_prenom',
        'dossiers.agent_id', 'agents.nom as agent_nom', 'agents.prenom as agent_prenom',
        'programmes.site')
        ->where('dossiers.id', '=', $id)->get(); 
        //dd($dossier); 
        
        $parcelles_clients = DB::table('parcelles')
        ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
        ->select('parcelles.id' , 'programmes.site', 'parcelles.numero', 'parcelles.surface')
        ->where('id_client', '=', $dossier[0]->client_id)
        ->where('programmes.id', '=', $dossier[0]->programme_id)
        ->get();
        
        $parcelles = DB::table('parcelles')
        ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
        ->select('parcelles.id' , 'programmes.site', 'parcelles.numero', 'parcelles.surface')
        ->get();

        $clients = Client::all(); 

        $agents = Agent::all(); 

        return view('dossier.edit')
                ->with('dossier', $dossier)
                ->with('parcelles_clients', $parcelles_clients)
                ->with('parcelles', $parcelles)
                ->with('clients', $clients)
                ->with('agents', $agents); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
     
        $this->validate($request, [
            'client' => 'required', 
            'parcelle_dispo' => 'required', 
            'date' => 'required', 
            'duree_contrat' => 'required|integer',
            'montant' => 'required'
        ]); 

        $programme = DB::table('programmes')
        ->join('parcelles', 'parcelles.id_site', '=', 'programmes.id')
        ->select('programmes.id', 'programmes.site')
        ->where('parcelles.id', '=', $request->parcelle_dispo[0])->get();

        $parcelles = Parcelle::where('id_site', '=', $programme[0]->id)
        ->where('id_client', '=', $request->client)->get(); 
      
        foreach($parcelles as $p)
        {
            $parcelle = Parcelle::find($p->id);
            $parcelle->id_client = 0; 
            $parcelle->etat = 'non réservé';
            $parcelle->id_dossier = 0;
            $parcelle->save(); 
        }
        
        foreach($request->parcelle_dispo as $pd)
        {
            $parcelle = Parcelle::find($pd); 
            $parcelle->id_client = $request->client; 
            $parcelle->etat = 'réservé'; 
            $parcelle->id_dossier = $id; 
            $parcelle->save(); 
        }

   

        $dossier = Dossier::find($id); 
        
        $dossier->client_id = $request->client;
        $dossier->agent_id = $request->agent_id;
        $dossier->programme_id = $programme[0]->id;
        $dossier->date = $request->date;
        $dossier->reference = 1;
        $dossier->duree_contrat = $request->duree_contrat;
        $dossier->etat = $request->duree_contrat;
        $dossier->montant_contrat = $request->montant;
        $dossier->save();

        /*
            Dossier::create([
                'client_id' => $request->client, 
                'agent_id' => $request->agent_id, 
                'programme_id' => $programme[0]->id,
                'date' => $request->date, 
                'reference' => 1 ($client->prenom)[0].''.($client->nom)[0]. '00'. (Dossier::count() + 1), 
                'duree_contrat' => $request->duree_contrat, 
                'etat' => 'ouvert', 
                'montant_contrat' => $request->montant, 
                'montant_verse' => 0,
            ]); 
        */

        Session::flash('success', 'Dossier modifié avec succée !'); 
        
        return redirect()->route('dossier.index'); 

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        Dossier::destroy($request->dossier_id); 

        Session::flash('success', 'Dossier supprime avec succee !'); 

        return redirect()->back(); 
    }
}
