<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Parcelle; 
use App\Models\Programme; 
use Session; 
use DB; 

class ParcelleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //

        $parcelles = DB::table('parcelles')
            ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
            ->select('parcelles.id', 'programmes.site', 'parcelles.numero', 'parcelles.surface', 'parcelles.etat', 'parcelles.id_client')
            ->orderBy('parcelles.numero', 'asc')
            ->get();
        
       /* $programme = ''; 

        if($parcelles->count() != 0) {
            $programme = Programme::find($parcelles[0]->id_site)->site; 
        }
        */

        return view('parcelle.index')->with('parcelles', $parcelles); 

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        
        $this->validate($request, [
            'numero' => 'required',
            'surface' => 'required' 
        ]); 

        $parcelle = DB::table('parcelles')
        ->where('id_site', $request->id_programme)
        ->where('numero', $request->numero)->get();
    
        if($parcelle->count() != 0)
        {
            Session::flash('warning', 'Ce numéro de parcelle existe déjà !');

            return redirect()->back(); 
        }
            //dd($request->id_programme);
        Parcelle::create([
            'id_site' => $request->id_programme, 
            'id_dossier' => 0,
            'id_client' => 0,
            'numero' => $request->numero,
            'surface' => $request->surface, 
            'montant' => 0,
            'etat' => 'non réservé'
        ]);

        Session::flash('success', 'Parcelle ajoute avec succee !');

        return redirect()->back(); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //

        $parcelle = Parcelle::find($id); 
     
        return view('parcelle.edit')->with('parcelle', $parcelle); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // 
        $this->validate($request, [
            'numero' => 'required',
            'surface' => 'required'
        ]);

        $parcelle = Parcelle::find($id);

        $parcelle->numero = $request->numero;
        $parcelle->surface = $request->surface; 

        if($request->client != null)
        {
            $parcelle->id_client = $request->client;
            $parcelle->etat = 'réservé'; 
        }
        else 
        {   
            $parcelle->id_client = 0; 
            $parcelle->etat = 'non réservé'; 
        }
         
        $parcelle->save(); 

        Session::flash('success', 'Parcelle modifie avec succee !'); 

        return redirect()->route('parcelle.index', $id);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        //  

        Parcelle::destroy($request->parcelle_id);

        Session::flash('success', 'Parcelle supprime avec succee !'); 

        return redirect()->back(); 
    }
}
