<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Programme; 
use Session; 
use DB; 

class ProgrammeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $programmes = Programme::all(); 

        return view('programme.index')->with('programmes', $programmes); 
    }

    public function notefrai($idSite) 
    {
        $notefrai = DB::table('note_frais')
            ->join('programmes', 'programmes.id', '=', 'note_frais.id_site')
            ->select('note_frais.type', DB::raw('SUM(note_frais.montant) as total'), 'note_frais.annee')
            ->groupBy('note_frais.type', 'note_frais.annee')
            ->where('note_frais.id_site', '=', $idSite)->get(); 
        $site = Programme::find($idSite)->site; 
        
        return view('programme.notefrai')
                ->with('notefrai', $notefrai)
                ->with('site', $site)
                ->with('idSite', $idSite); 
    }

    public function entree($idSite) 
    {
      
        $entrees = DB::table('versements')
            ->join('entrees', 'entrees.id_versement', '=', 'versements.id')
            ->select(DB::raw('SUM(versements.montant) as total'), 'versements.annee')
            ->groupBy('versements.annee')
            ->where('entrees.id_site', '=', $idSite)->get(); 
      
        $site = Programme::find($idSite)->site; 
        return view('programme.entree')->with('entrees', $entrees)
        ->with('site', $site)
        ->with('idSite', $idSite); 
    }

    public function benefice($idSite)
    {
        $entrees = DB::table('versements')
        ->join('entrees', 'entrees.id_versement', '=', 'versements.id' )
        ->select(DB::raw('SUM(versements.montant) as total'), 'versements.annee')
        ->groupBy('annee')->where('entrees.id_site', '=', $idSite)->get(); 

        $notefrais = DB::table('note_frais')
        ->select(DB::raw('SUM(montant) as total'), 'annee')
        ->groupBy('annee')->where('id_site', '=', $idSite)
        ->get(); 

        $site = Programme::find($idSite)->site; 

        return view('programme.benefice')
        ->with('entrees', $entrees)
        ->with('notefrais', $notefrais)
        ->with('site', $site)
        ->with('idSite', $idSite);; 
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //

        return view('programme.create'); 
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
      
        $this->validate($request, [
            'site' => 'required',
        ]);

        Programme::create([
            'site' => $request->site, 
        ]);

        Session::flash('success', 'Programme ajoute avec succee !'); 
        return redirect()->route('programme.index'); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $programme = Programme::find($id); 

        return view('programme.edit')->with('programme', $programme); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        //
        $this->validate($request, [
            'site' => 'required',
        ]);

        $programme = Programme::find($id); 

        $programme->site = $request->site; 
       
        $programme->save(); 

        Session::flash('success', 'Programme modifie avec succee !'); 
        return redirect()->route('programme.index'); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        //
        Programme::destroy($request->programme_id); 

        Session::flash('success', 'Programme supprime avec succee !'); 

        return redirect()->back(); 
    }
}
