<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Agent; 
use Session; 
use Illuminate\Support\Facades\Auth; 
use DB; 

class TuteurCommercialController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $agents = Agent::all();

        return view('egent.index')->with('agents', $agents); 
    }

    public function MesAgents()
    {
        //
        $tuteurs_commercials = DB::table('dossiers')
        ->join('tuteur_commercials', 'tuteur_commercials.id', '=', 'dossiers.tuteur_commercial_id')
        ->select('tuteur_commercials.nom', 'tuteur_commercials.prenom', 'tuteur_commercials.telephone', 'tuteur_commercials.email')
        ->where('dossiers.client_id', '=', Auth::user()->client_id)
        ->get();

        return view('tuteur_commercial.agents')->with('tuteurs_commercials', $tuteurs_commercials); 
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        return view('agent.create'); 
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validate($request, [
            'nom' => 'required', 
            'prenom' => 'required', 
            'telephone' => 'required', 
        ]); 

        Agent::create([
            'nom' => $request->nom, 
            'prenom' => $request->prenom, 
            'telephone' => $request->telephone,
            'email' => $request->adresse_email
        ]); 
        
        Session::flash('success', 'Ajoute avec succee !'); 

        return redirect()->route('tuteur_commercial.index'); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $tuteur_commercial = TuteurCommercial::find($id); 

        return view('tuteur_commercial.edit')->with('tuteur_commercial', $tuteur_commercial); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        
        $this->validate($request, [
            'nom' => 'required', 
            'prenom' => 'required', 
            'telephone' => 'required', 
        ]); 
        
        $tuteur_commercial = TuteurCommercial::find($id); 
        
        $tuteur_commercial->nom = $request->nom;
        $tuteur_commercial->prenom = $request->prenom; 
        $tuteur_commercial->email = $request->adresse_email; 
        $tuteur_commercial->telephone = $request->telephone; 

        $tuteur_commercial->save(); 


        Session::flash('success', 'Tuteur Commercial modifie avec succee !'); 

        return redirect()->route('tuteur_commercial.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        //
 
        TuteurCommercial::destroy($request->tuteur_commercial_id); 

        Session::flash('success', 'Tuteur/Commercial supprime avec succee !'); 

        return redirect()->back(); 
    }
}
