<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Request;
use App\Models\User; 
use DB; 
use Session; 

class UtilisateurController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $utilisateurs = User::all(); 
      
        return view('utilisateur.index')->with('utilisateurs', $utilisateurs); 
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        return view('utilisateur.create'); 
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
     
        $this->validate($request, [
            'nom' =>  'required',
            'prenom' => 'required',
            'email' => 'required|unique:users', 
            'password' => 'required|confirmed',
        ]); 
        
        if($request->type == null) {
            User::create([
                'nom' => $request->nom,
                'prenom' => $request->prenom, 
                'email' => $request->email,
                'password' => Hash::make($request->password),
                //'telephone' => $request->telephone 
                'type' => 'Super Administrateur'
            ]); 
        } else {
            User::create([
                'nom' => $request->nom,
                'prenom' => $request->prenom, 
                'email' => $request->email,
                'password' => Hash::make($request->password),
                //'telephone' => $request->telephone 
                'type' => $request->type
            ]); 
        }
        
        Session::flash('success', 'Utilisateur ajoute avec succee !'); 

        return redirect()->route('utilisateur.index'); 
    } 

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //

        $utilisateur = User::find($id); 

        return view('utilisateur.edit')->with('utilisateur', $utilisateur); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
       

        $this->validate($request, [
            'nom' =>  'required',
            'prenom' => 'required',
            'email' => 'required', 
            'password' => 'required|confirmed',
        ]); 

        $utilisateur = User::find($id); 
        
        $utilisateur->nom = $request->nom; 
        $utilisateur->prenom = $request->prenom; 
        $utilisateur->email = $request->email; 
        $utilisateur->password = Hash::make($request->password); 

        $utilisateur->save();

        Session::flash( 'success', 'Utilisateur modifie avec succee !'); 

        return redirect()->route('utilisateur.index'); 

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        //
        User::destroy($request->id_utilisateur); 

        return redirect()->back(); 
    }
}
