<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Client;
use App\Models\Dossier; 
use App\Models\Versement; 
use App\Models\Programme; 
use App\Models\BanqueCaisse; 
use App\Models\JournalTresorerie;
use App\Models\JournalCaisse; 
use App\Models\Entree; 
use Illuminate\Support\Facades\Auth; 
use DB; 
use Carbon\Carbon; 
use Session;

class VersementController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        /*
            $versements = DB::table('versements')
            ->join('clients', 'clients.id', '=', 'versements.client_id')
            ->select('clients.id as client_id', DB::raw('SUM(versements.montant) as total'), 'versements.annee')
            ->groupBy('clients.id', 'versements.annee')
            ->get(); 
        */

        $versements = DB::table('versements')
        ->join('clients', 'clients.id', '=', 'versements.client_id')
        ->select('versements.id', 'clients.nom', 'clients.prenom', 'versements.montant', 'versements.date')
        ->orderBy('clients.id', 'desc')
        ->orderBy('versements.id', 'asc')

        ->get(); 

        //$clients = Client::all(); 
    
        return view('versement.index')->with('versements', $versements); 
    }

    public function restant()
    {
        $versements = DB::table('versements')
            ->select(DB::raw('SUM(versements.montant) as total'), 'versements.dossier_id')
            ->groupBy('versements.dossier_id')
            ->get();
 
        $dossiers = DB::table('dossiers')
            ->join('clients', 'clients.id', '=', 'dossiers.client_id')
            ->join('parcelles', 'parcelles.id', '=', 'dossiers.parcelle_id')
            ->select('dossiers.id', 'clients.prenom', 'clients.nom', 'parcelles.numero', 'parcelles.surface', 'parcelles.montant')
            ->get(); 
      
        return view('versement.restant')
                ->with('dossiers', $dossiers)
                ->with('versements', $versements); 
    }

    public function MesVersements()
    {
        //
       $versements = DB::table('versements')
        ->join('dossiers', 'dossiers.id', '=', 'versements.dossier_id')
        ->select('versements.id', 'versements.libelle', 'versements.montant', 'versements.created_at', 'dossiers.reference')
        ->where('versements.client_id', '=', Auth::user()->client_id)
        ->get(); 
        
        return view('versement.mes_versements')->with('versements', $versements); 
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $clients = Client::all();
        $dossiers = Dossier::all(); 
        
        return view('versement.create')->with('clients', $clients)->with('dossiers', $dossiers); 
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
            //dd($request->fichier->extension());
            
        $this->validate($request, [
            'montant' => 'required|integer',
            'date' => 'required'
        ]);   
            
        $fileName = ''; 
  
        if($request->fichier != null) {
  
            $fileName = time().'.'.$request->fichier->extension();  

            $request->fichier->move(public_path('uploads/fichier_joint'), $fileName);
           
        }
        
        if($request->programme == null)
        {
            Session::flash('warning', 'Veuillez choisir un programme ou site correspondant au versement du client !');

            return redirect()->back(); 
        }
        
        Versement::create([
            'client_id' => $request->client_id, 
            'dossier_id' => $request->dossier_id, 
            'libelle' => $request->type,
            'date' => $request->date, 
            'montant' => $request->montant,
            'mois' => (new Carbon())->month, 
            'annee' => (new Carbon())->year,
            'mode_paiement' => $request->mode_paiement, 
            'fichier' => $fileName
        ]); 
        /*
       
        */
   
        $versement = DB::table('versements')
            ->where('client_id', '=', $request->client_id)
            ->where('dossier_id', '=', $request->dossier_id)
            ->where('montant', '=', $request->montant)
            ->where('libelle', '=', $request->type)
            ->where('mois', '=', (new Carbon())->month)
            ->get(); 
        /*
            $dossier = DB::table('dossiers')->where('id', '=', $request->dossier_id)->get();
            $parcelle = DB::table('parcelles')->where('id', '=', $dossier[0]->parcelle_id)->get();
        */
        Entree::create([
            'id_site' => $request->programme,
            'id_versement' => $versement[0]->id 
        ]);

        $versement = DB::table('versements')
            ->select('dossier_id', DB::raw('SUM(montant) as montant_verse'))
           ->where('dossier_id', '=', $request->dossier_id)->groupBy('dossier_id')->get();

        $dossier = Dossier::find($request->dossier_id); 
        $dossier->montant_verse = $versement[0]->montant_verse;
        $dossier->save();

        if($dossier->montant_verse >= $dossier->montant_contrat)
        {
            $dossier->etat = 'fermé';
            $dossier->save(); 
        }
        Session::flash('success', 'Versement ajoute avec succee !'); 

        return redirect()->back(); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($idClient, $annee)
    {
        //
        $versements = DB::table('versements')
            ->join('clients', 'clients.id', '=', 'versements.client_id')
            ->join('dossiers', 'dossiers.id', '=', 'versements.dossier_id')
            ->select('versements.id', 'versements.libelle', 'clients.nom', 'clients.prenom', 'versements.montant', 'versements.mode_paiement', 'versements.fichier', 'versements.mois', 'versements.updated_at', 'dossiers.id as dossier_id')
            ->where('versements.client_id', '=', $idClient)->where('versements.annee', '=', $annee)->get(); 
  
        $dossiers = Dossier::all(); 
        return view('versement.show')->with('versements', $versements)->with('dossiers', $dossiers); 
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $versement = Versement::find($id); 
        
        return view('versement.edit')->with('versement', $versement); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        $this->validate($request, [
            'montant' => 'required|integer' 
        ]);  

        $filename = '';

        if($request->fichier != null) {
            $fileName = time().'.'.$request->fichier->extension();  

            $request->photo->move(public_path('uploads/fichier_joint'), $fileName);
        }
        
        $versement = Versement::find($id); 

        $versement->montant = $request->montant; 
        $versement->mois = (new Carbon())->month; 
        $versement->annee = (new Carbon())->year; 
        $versement->mode_paiement = $request->mode_paiement; 
        $versement->fichier = $filename; 

        $versement->save(); 

        Session::flash('success', 'Versement modifie avec succee !'); 
        
        return redirect()->route('versement.index'); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        //
        
        $versement = Versement::find($request->versement_id);

        $dossier = Dossier::find($versement->dossier_id); 
        $dossier->montant_verse -= $versement->montant; 
        $dossier->save();

        Versement::destroy($request->versement_id); 

        Session::flash('success', 'Versement supprimé avec succée !'); 

        return redirect()->back(); 
    }
}
