<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Visite; 
use App\Models\Client;
use App\Models\Programme; 
use App\Models\Parcelle; 
use App\Models\Agent; 
use DB; 
use Session; 

class VisiteController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $visites = DB::table('visites')
        ->join('clients', 'clients.id', '=', 'visites.id_client')
        ->join('parcelles', 'parcelles.id', '=', 'visites.id_parcelle')
        ->join('agents', 'agents.id', '=', 'visites.id_agent')
        ->select('visites.id', 'clients.nom', 'clients.prenom', 'clients.telephone', 'parcelles.id_site', 'parcelles.numero', 'parcelles.id as parcelle_id' ,'parcelles.surface', 'agents.nom as agent_nom', 'agents.prenom as agent_prenom', 'visites.commentaires', 'visites.created_at')
        ->get(); 


        return view('visite.index')
        ->with('visites', $visites)
        ->with('programmes', Programme::all()); 
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $parcelles = DB::table('parcelles')
        ->join('programmes', 'programmes.id', '=', 'parcelles.id_site')
        ->select('parcelles.id', 'programmes.site', 'parcelles.numero', 'parcelles.surface', 'parcelles.etat')
        ->where('parcelles.etat', '=', 'non réservé')->get(); 

        return view('visite.create')
                ->with('clients', Client::all())
                ->with('programmes', Programme::all())
                ->with('parcelles', $parcelles)
                ->with('agents', Agent::all()); 
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    
        $this->validate($request, [
            'client' => 'required',
            'parcelle' => 'required', 
            'agent' => 'required'
        ]);
        
        Visite::create([
            'id_client' => $request->client,
            'id_parcelle' => $request->parcelle, 
            'commentaires' => $request->commentaires ? $request->commentaires : '', 
            'id_agent' => $request->agent 
        ]);

        Session::flash('success', 'Visite ajouté avec succés !'); 

        return redirect()->route('visite.index'); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        //
        
        Visite::destroy($request->id_visite);

        Session::flash('success', 'Visite supprimé avec succé !');

        return redirect()->back(); 
    }
}
